==> twinlisp-0.1.1.tar.gz: twinlisp/compile-core.lisp <==
;
;Copyright (C) 2006 Mikalai Birukou
;
;This file is part of TwinLisp.
;
;    TwinLisp is free software; you can redistribute it and/or modify
;    it under the terms of the GNU General Public License as published by
;    the Free Software Foundation; either version 2 of the License, or
;    (at your option) any later version.
;
;    TwinLisp is distributed in the hope that it will be useful,
;    but WITHOUT ANY WARRANTY; without even the implied warranty of
;    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;    GNU General Public License for more details.
;
;    You should have received a copy of the GNU General Public License
;    along with TwinLisp; if not, write to the Free Software
;    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
(load "core/PackDef.lisp")
(tl-set-home-path "" "/")
(load "core/loadTL.lisp")
(compile-file "core/PackDef.lisp")
(compile-file "core/loadTL.lisp")
(compile-file "core/OtherMacs.lisp")
(compile-file "core/ContainerTypesAndMacs.lisp")
(compile-file "core/OperMacs.lisp")
(compile-file "core/OtherMeths.lisp")
(compile-file "core/OtherFuncs.lisp")
(compile-file "core/ContainerMeths.lisp")
(compile-file "core/OperMeths.lisp")
(compile-file "core/TranslConst.lisp")
(compile-file "core/TranslStringReading.lisp")
(compile-file "core/TranslElemSearchFuncs.lisp")
(compile-file "core/TranslFormBuilding.lisp")
(compile-file "core/TranslFormWritting.lisp")
(compile-file "core/LoaderMacs.lisp")
(compile-file "core/interpreter.lisp")

==> twinlisp-0.3.2.tar.gz: twinlisp/compile-core.lisp <==
;
;Copyright (C) 2006 Mikalai Birukou
;
;This file is part of TwinLisp.
;
;    TwinLisp is free software; you can redistribute it and/or modify
;    it under the terms of the GNU General Public License as published by
;    the Free Software Foundation; either version 2 of the License, or
;    (at your option) any later version.
;
;    TwinLisp is distributed in the hope that it will be useful,
;    but WITHOUT ANY WARRANTY; without even the implied warranty of
;    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;    GNU General Public License for more details.
;
;    You should have received a copy of the GNU General Public License
;    along with TwinLisp; if not, write to the Free Software
;    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
(cl:load "core/PackDef.lisp")
(tl-set-home-path "" "/")
(cl:load "core/loadTL.lisp")
(compile-file "core/PackDef.lisp")
(compile-file "core/loadTL.lisp")
(compile-file "core/OtherMacs.lisp")
(compile-file "core/ContainerTypesAndMacs.lisp")
(compile-file "core/OperMacs.lisp")
(compile-file "core/OtherMeths.lisp")
(compile-file "core/OtherFuncs.lisp")
(compile-file "core/ContainerMeths.lisp")
(compile-file "core/OperMeths.lisp")
(compile-file "core/TranslConst.lisp")
(compile-file "core/TranslStringReading.lisp")
(compile-file "core/TranslElemSearchFuncs.lisp")
(compile-file "core/TranslFormBuilding.lisp")
(compile-file "core/TranslFormWritting.lisp")
(compile-file "core/LoaderMacs.lisp")
(compile-file "core/interpreter.lisp")
